Lua_BeastSoulPropPanel = class("Lua_BeastSoulPropPanel", Lua_DisplayObject);
function Lua_BeastSoulPropPanel:ctor(p)	
	self:superCall("ctor", p, "BeastSoulPropPanel_skin");
end

function Lua_BeastSoulPropPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(10);
    self.itemImg:setLocation(-90, -300, 0);
    self.itemImg:setCanClick(true);

    self.dragContainer = Lua_DragContainer.new(self.content, 1, Vector4(120, -87, 276, 222));
    self.dragContainer:setLocation(-120, 87, 0);
    self.dragContainer.canDrag = false;

    self.skillIcon.clickScale = false;
	self.skillIcon:addClickFuntion(self, self.onSkillIconClick);
    self.subBtn:addClickFuntion(self, self.onSubBtnClick);
end

function Lua_BeastSoulPropPanel:dispose()
	if self.dragContainer ~= nil then
		self.dragContainer:removeAllChildren();
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end

	self:superCall("dispose");
end

function Lua_BeastSoulPropPanel:setData(data, _type)
	self.data = data;
	self._type = _type;

	local arr = nil;
	local costVo = nil;
	self.skillVo = nil;

	if _type == 1 then -- 升星
		if data.isActivate == 0 or (data.isActivate == 1 and data.starLvl == 0) then
			arr = data.baseAttrsArr;
			costVo = data.activateCostVo;
		else
			arr = data.starAttrsArr;
			costVo = data.upStarCostVo;
		end
		self.skillVo = data.upStarSkill;

		if self.skillVo.isActivate == 0 then
			self.skillIcon:setGray(true);
			self.skillLevel.text = LanUtil.getValue(143478);
			self.subBtn.label = LanUtil.getValue(143406);
		else
			self.skillIcon:setGray(false);
			self.skillLevel.text = "Lv."..self.skillVo.level;
			self.subBtn.label = LanUtil.getValue(143473);
		end
		self.skillIcon:setAltas(self.skillVo.atlasName, self.skillVo.iconName);

		if data.isMaxUpStar then
			self.itemImg:setEnable(false);
			self.maxDes:setEnable(true);
			self.redDot:setEnable(false);
			self.subBtn:setBtnEnable(false);
		else
			self.itemImg:setEnable(true);
			self.maxDes:setEnable(false);
			self.redDot:setEnable(data.isShowUpStarRed);
			self.subBtn:setBtnEnable(true);
		end
	elseif _type == 2 then -- 强化
		arr = data.intensifyAttrsArr;
		costVo = data.intensifyCostVo;
		self.skillVo = data.intensifySkill;

		if self.skillVo.isActivate == 0 then
			self.skillIcon:setGray(true);
			self.skillLevel.text = LanUtil.formateStr(LanUtil.getValue(143479), tostring(self.skillVo.upCondition));
		else
			self.skillIcon:setGray(false);
			self.skillLevel.text = "Lv."..self.skillVo.level;
		end
		self.subBtn.label = LanUtil.getValue(143474);
		self.skillIcon:setAltas(self.skillVo.atlasName, self.skillVo.iconName);

		if data.isMaxIntensify then
			self.itemImg:setEnable(false);
			self.maxDes:setEnable(true);
			self.redDot:setEnable(false);
			self.subBtn:setBtnEnable(false);
		else
			self.itemImg:setEnable(true);
			self.maxDes:setEnable(false);
			self.subBtn:setBtnEnable(true);

			if data.isMaxCurrentIntensify then
				self.redDot:setEnable(false);
			else
				self.redDot:setEnable(data.isShowIntensifyRed);
			end
		end
	end

	self.dragContainer:removeAllChildren();
	if arr ~= nil then
		local len = arr:getSize();
		for i = 1, len do
			local item = Lua_BeastSoulPropItem.new(self.dragContainer.content);
			item:setData(arr[i]);
			self.dragContainer:addSubContainer(item, false);
		end
		self.dragContainer:updateChildPos();
	end

	if costVo ~= nil then
	    self.itemImg.data = costVo;
	    self.itemImg:showNumLimit(costVo.haveNum, costVo.count, 2);
	end
end

function Lua_BeastSoulPropPanel:onSkillIconClick(go)
	Lua_WindowUtil.openWin("Lua_BeastSoulSkillDetailWindow", WinParam.ACTION_OPEN, self.skillVo);
end

function Lua_BeastSoulPropPanel:onSubBtnClick(go)
	if self._type == 1 then
		if self.data.isActivate == 0 then
			Lua_ProxyManager.getProxy("Lua_BeastSoulProxy"):sActivateBeastSoul(self.data.id);
		else
			Lua_ProxyManager.getProxy("Lua_BeastSoulProxy"):sBeastSoulUpStar(self.data.id);
		end
	elseif self._type == 2 then
		Lua_ProxyManager.getProxy("Lua_BeastSoulProxy"):sIntensifyBeastSoul(self.data.id);
	end
end





















Lua_BeastSoulPropItem = class("Lua_BeastSoulPropItem", Lua_DragContainerItem);
function Lua_BeastSoulPropItem:ctor(p)	
	self:superCall("ctor", p, "BeastSoulPropItem_skin");
end

function Lua_BeastSoulPropItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_BeastSoulPropItem:dispose()
	self:superCall("dispose");
end

function Lua_BeastSoulPropItem:setData(data)
	self.data = data;
	self.currLabel.text = "[3F6182]"..data.name..": [-][192E41]"..data.value.."[-]";

	if data.nextValue == nil or data.nextValue == 0 then
		self.arrowSp:setEnable(false);
		self.nextLabel:setEnable(false);
	else
		self.arrowSp:setEnable(true);
		self.nextLabel:setEnable(true);
		self.nextLabel.text = "[13A100]"..data.nextValue.."[-]";
	end
end

function Lua_BeastSoulPropItem:getHeight()
    return self.currLabel.height + 15;
end

function Lua_BeastSoulPropItem:getOffsetX()
    if self.data.nextValue == nil or data.nextValue == 0 then
    	return 45;
    else
    	return 0;
    end
end