Lua_BeastSoulResolveWindow = class("Lua_BeastSoulResolveWindow", Lua_SecondSizeWindow);
function Lua_BeastSoulResolveWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_BeastSoulResolveWindow";
	self.skinName = "BeastSoulResolveWindow_skin";
	self.titleText = LanUtil.getValue(143411);
end

function Lua_BeastSoulResolveWindow:buildShowItem()
	self:superCall("buildShowItem");

    self.resolveArr = Array();

	self.packList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 962, 436));
    self.packList:setLocation(6, 16, 0);
    self.packList:setListCell(Lua_BeastSoulResolveItem, 90, 97, 10);

    self.cost_217040002.clickScale = false;
    self.cost_217040002:addClickFuntion(self, self.onCostItemClick);
    self.cost_217040003.clickScale = false;
    self.cost_217040003:addClickFuntion(self, self.onCostItemClick);
    self.cost_217040004.clickScale = false;
    self.cost_217040004:addClickFuntion(self, self.onCostItemClick);

	self.resolveBtn:addClickFuntion(self, self.onResolveBtnClick);

	self:addLuaEvent("UPDATE_BEASTSOUL_RESOLVE_SELCET", self, self.onSelectInfo);
    self:addLuaEvent("PACK_UPDATE", self, self.updatePackInfo);
	self:updatePackInfo();
	self:updatePackInfo();
end

function Lua_BeastSoulResolveWindow:dispose()
	if self.packList ~= nil then
		self.packList:dispose();
		self.packList = nil;
	end

	self:superCall("dispose");
end

function Lua_BeastSoulResolveWindow:onSelectInfo()
    self:updateSelect();
    self:updateResolveData();
end

function Lua_BeastSoulResolveWindow:updateSelect()
    if self.packList ~= nil then
        local arr = self.packList.showList;
        local len = arr:getSize();
        for i = 1, len do
            arr[i]:updateSelect();
        end
    end
end

function Lua_BeastSoulResolveWindow:updatePackInfo()
	local bagData = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK);
    local arr = bagData:getBagAllData();
    local len = DataCenter.beastSoulUtil.packSize;
    self.resolveList = Array();
    for i = 1, len do
        if arr[i] ~= nil and (arr[i].subType == Lua_PackTypeDefine.ZODIAC_BEASTSOUL_RESOLVE or arr[i].subType == Lua_PackTypeDefine.ZODIAC_BEASTSOUL) then
            local sortNum = 0;
            local isSelect = false;

            if arr[i].subType == Lua_PackTypeDefine.ZODIAC_BEASTSOUL_RESOLVE then
                sortNum = arr[i].type_sort;
                isSelect = true;
            elseif arr[i].subType == Lua_PackTypeDefine.ZODIAC_BEASTSOUL then
                sortNum = 100 + arr[i].type_sort;
                isSelect = false;
            end

            self.resolveList:add({ vo = arr[i], isSelect = isSelect, sortNum = sortNum });
        else
            self.resolveList:add({ vo = nil, isSelect = false, sortNum = 99999999 });
        end
    end

    self.resolveList:sort("sortNum", false);
	self.packList:setLuaArrayData(self.resolveList, false);

    self:updateResolveData();
end

function Lua_BeastSoulResolveWindow:updateResolveData() -- 分解数据
    self.resolveArr:clear();
    local len = self.resolveList:getSize();
    for i = 1, len do
        if self.resolveList[i].isSelect == true then
            local list = {};
            list.index = self.resolveList[i].vo.index;
            list.id = self.resolveList[i].vo.id;
            list.count = self.resolveList[i].vo.count;
            self.resolveArr:add(list);      
        end
    end

    if self.resolveArr:getSize() > 0 then
        self.costNum_1.text = DataCenter.beastSoulUtil:getResolveTotalNum(self.resolveArr, 217040002);
        self.costNum_2.text = DataCenter.beastSoulUtil:getResolveTotalNum(self.resolveArr, 217040003);
        self.costNum_3.text = DataCenter.beastSoulUtil:getResolveTotalNum(self.resolveArr, 217040004);
    else
        self.costNum_1.text = 0;
        self.costNum_2.text = 0;
        self.costNum_3.text = 0;
    end
end

function Lua_BeastSoulResolveWindow:onCostItemClick(go)
    local str = string.split(tostring(go.gameObject.name), "_");
    local vo = DataCenter.beastSoulUtil:getCostVoById(tonumber(str[2]));
    if vo ~= nil then
        Lua_PackUtil.showItemInfo(vo);
    end
end

function Lua_BeastSoulResolveWindow:onResolveBtnClick(go)
    if self.resolveArr:getSize() <= 0 or self.resolveArr == nil then
        OperateAlert.show(LanUtil.getValue(143492));
        return;
    end
	Lua_ProxyManager.getProxy("Lua_BeastSoulProxy"):sResolveBeastSoul(self.resolveArr);

    if self.resolveList ~= nil then
        self.resolveList:clear();
    end

    if self.resolveArr ~= nil then
        self.resolveArr:clear();
    end
end




















Lua_BeastSoulResolveItem = class("Lua_BeastSoulResolveItem", Lua_ListCell);
function Lua_BeastSoulResolveItem:ctor(p)
    self:superCall("ctor", p, nil);
end

function Lua_BeastSoulResolveItem:buildShowItem()
    self:superCall("buildShowItem");

    self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(3);
    self.itemImg:setLocation(0, 0, 0);
    self.itemImg:setCanClick(false);

    self.tick = UICreate.createUIAtlasImage(self.content, "iconantlas1", "tick_green", 0, 6, 0, 0);
    self.tick:setDepth(10);
    self.tick:setEnable(false);
end

function Lua_BeastSoulResolveItem:dispose()
    self:superCall("dispose");
end

function Lua_BeastSoulResolveItem:setData(data)
    self.data = data;

    self.itemImg.data = data.vo;
    self:updateSelect();
end

function Lua_BeastSoulResolveItem:updateSelect()
    if self.data.isSelect == true then
        self.tick:setEnable(true);
        self.itemImg:setGray(true);
    else
        self.tick:setEnable(false);
        self.itemImg:setGray(false);
    end
end

function Lua_BeastSoulResolveItem:onPlayerSoundClick(go)
    if self.data.vo ~= nil then
        if self.data.isSelect == true then
            self.data.isSelect = false;
        else
            self.data.isSelect = true;
        end
        Lua_MsgUtil.callFunc("UPDATE_BEASTSOUL_RESOLVE_SELCET");
    end
end