checkRequire("Lua_SecretItem");
Lua_SecretPanel = class("Lua_SecretPanel", Lua_DisplayObject);
function Lua_SecretPanel:ctor(p)    
    self:superCall("ctor", p, "SecretPanel_skin");
end

function Lua_SecretPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.startIdx = 1;
    self.rewardsArr = Array();
    self.itemArray = Array();
    local posX = {-495, -280, -60, 160, 380};
    for i = 1, 5 do
        local item = Lua_SecretItem.new(self.content);
        item:setLocation(posX[i], -185, 0);
        self.itemArray:add(item);
    end

    self.rewardList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 700, 240));
    self.rewardList:setLocation(-50, 58, 0);
    self.rewardList:setListCell(Lua_SecretRewardItem, 110, 140, 5);
    self.rewardList.canDrag = false;

    self.packRedDot:setEnable(false);

    self.packBtn:addClickFuntion(self, self.onPackBtnClick);
    self.helpBtn:addClickFuntion(self, self.onHelpBtnClick);

    self.callBtn_1.label = LanUtil.getValue(143493);
    self.callBtn_1:addClickFuntion(self, self.onCallBtn1Click);

    local oneBuyCount = DataCenter.secretUtil.oneBuyCount;
    self.callBtn_2.label = LanUtil.formateStr(LanUtil.getValue(143490));
    self.callBtn_2:addClickFuntion(self, self.onCallBtn2Click);

    local tenBuyCount = DataCenter.secretUtil.tenBuyCount;
    self.callBtn_3.label = LanUtil.formateStr(LanUtil.getValue(143491));
    self.callBtn_3:addClickFuntion(self, self.onCallBtn3Click);

    Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretInfo();
    self:addLuaEvent("UPDATE_SECRET", self, self.updatePanelInfo);
    self:addLuaEvent("PACK_UPDATE", self, self.onPackDataUpdate);
end

function Lua_SecretPanel:dispose()
    for i = 1, self.itemArray:getSize() do
        self.itemArray[i]:dispose();
    end
    self.itemArray:clear();

    for i = 1, self.rewardsArr:getSize() do
        self.rewardsArr[i]:dispose();
    end
    self.rewardsArr:clear();

    if self.rewardList ~= nil then
        self.rewardList:dispose();
        self.rewardList = nil;
    end

    DataCenter.secretData.drawType = nil;
    if self.bStart ~= nil and self.bStart == true then
        Lua_CommonUtil.removeTimer(self, self.playRewardItemEffect);
        self.bStart = false;
    end

    self:superCall("dispose");
end

function Lua_SecretPanel:updatePanelInfo()
    local one_DrawCount = DataCenter.secretData.one_DrawCount;
    local ten_DrawCount = DataCenter.secretData.ten_DrawCount;
    self.leftTime.text = LanUtil.formateStr(LanUtil.getValue(143438), tostring(one_DrawCount), tostring(ten_DrawCount));
    
    local arr = DataCenter.secretUtil.secretInfoArr;
    if arr ~= nil then
        local len = arr:getSize();
        for i = 1, len do
            local vo = arr[i];
            self.itemArray[i]:setData(vo);

            if vo.isBindGoldDraw == true then
                self.discount_1.text = LanUtil.formateStr(LanUtil.getValue(143440), tostring(vo.oneDiscount));
            end

            if vo.isGoldDraw == true then
                self.discount_2.text = LanUtil.formateStr(LanUtil.getValue(143440), tostring(vo.oneDiscount));
                self.discount_3.text = LanUtil.formateStr(LanUtil.getValue(143440), tostring(vo.tenDiscount));
            end
        end
    end

    local rArr = DataCenter.secretData.rewardsArr;
    if rArr:getSize() > 0 then -- 切换页签，如果没有抽奖记录则继续显示奖励预览，有抽奖记录则显示抽奖记录
        DataCenter.secretData.isShowReward = true;
    end

    if DataCenter.secretData.isShowReward == false then
        local showArr = DataCenter.secretUtil.rewardShowArr;
        self.tipsLabel:setEnable(true);
        self.rewardList:setEnable(true);
        self.rewardList:setLuaArrayData(showArr, false);
    else
        self.tipsLabel:setEnable(false);
        self.rewardList:setEnable(false);
        self:setShowResultData(rArr);
    end

    self:onPackDataUpdate(Lua_PackData.SECRET_PACK);
end

function Lua_SecretPanel:onPackDataUpdate(packType)
    if packType == Lua_PackData.SECRET_PACK then -- 临时仓库更新
        self.packRedDot:setEnable(DataCenter.secretData.showPackRedDot);
    end
end

function Lua_SecretPanel:setShowResultData(arr)
    if arr == nil then
        return;
    end

    local len = arr:getSize();
    if DataCenter.secretData.drawType == 0 then -- 单抽
        self.startIdx = len;
    elseif DataCenter.secretData.drawType == 1 then -- 十抽
        self.startIdx = 1;
    end

    for i = 1, self.rewardsArr:getSize() do
        self.rewardsArr[i]:dispose();
    end
    self.rewardsArr:clear();

    local startX = -330;
    local startY = 125;
    for i = 1, len do
        local item = Lua_SecretResultItem.new(self.content);
        local numX = (i - 1) % 5;
        local numY = math.floor((i - 1) / 5);
        item:setLocation(startX + numX * 140, startY - numY * 115, 0);
        item:setData(arr[i]);

        if DataCenter.secretData.drawType == 0 then
            if i == len then
                item:setScale(1.2, 1.2, 1.2);
                item:setEnable(false);
            else
                item:setEnable(true);    
            end
        elseif DataCenter.secretData.drawType == 1 then
            item:setScale(1.2, 1.2, 1.2);
            item:setEnable(false);
        else
            item:setEnable(true);
        end
        
        self.rewardsArr:add(item);
    end

    if DataCenter.secretData.drawType ~= nil then -- 手动召唤才显示动画
        if self.bStart == nil or self.bStart == false then
            Lua_CommonUtil.addTimer("playRewardItemEffect", 0.05, self, self.playRewardItemEffect, nil, -1);
            self.bStart = true;
        end
        self:playEffEct();
    end
end

function Lua_SecretPanel:playRewardItemEffect()
    if self.startIdx >= self.rewardsArr:getSize() then
        if self.bStart == true then
            Lua_CommonUtil.removeTimer(self, self.playRewardItemEffect);
            self.bStart = false;
        end
    end
    self:playEffEct();
    self.startIdx = self.startIdx + 1;
end

function Lua_SecretPanel:playEffEct()
    local item = self.rewardsArr[self.startIdx];
    if item ~= nil then
        item:setEnable(true);
        item:showQualityEff(true);
        TweenUtil.getInstance():addTween(item.content, 0.3, 0, nil, nil, Vector3(1, 1, 1));
    end
end

function Lua_SecretPanel:onPackBtnClick(go)
    Lua_WindowUtil.openWin("Lua_SecretPackWindow", WinParam.ACTION_OPEN);
end

function Lua_SecretPanel:onHelpBtnClick(go)
    Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_OPEN, LanUtil.getValue(143441));
end

function Lua_SecretPanel:onCallBtn1Click(go)
    DataCenter.secretData.drawType = 0;
    self.secretVo = nil;
    local arr = DataCenter.secretUtil.secretInfoArr;
    if arr ~= nil then
        local len = arr:getSize();
        for i = 1, len do
            if arr[i].isBindGoldDraw == true then
                self.secretVo = arr[i];
                break;
            end
        end
    end

    if self.secretVo == nil then
        return;
    end
    self.bEnoughBindGold = true;
    local str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.secretVo.oneDrawCost.."[-]";
    if DataCenter.moneyData:getMoney(Lua_MoneyData.BIND_GOLD) < self.secretVo.oneDrawCost then
        self.bEnoughBindGold = false;
        str = "["..Lua_ColorDefine.RED_STR.."]"..self.secretVo.oneDrawCost.."[-]";
    end

    if DataCenter.neverTip:getNeverValue("Secret_BindGold") == true then
        if self.bEnoughBindGold then
            Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 0, 1);
        else
            DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.BIND_GOLD, self.secretVo.oneDrawCost, true, false);
        end
        return;
    end

    local tipData = {};
    tipData.des = LanUtil.formateStr(LanUtil.getValue(143444), tostring(self.secretVo.oneDiscount), str);
    tipData.isSecret = true;
    tipData.neverTip = "Secret_BindGold";
    tipData.owner = self;
    tipData.type = 1;
    tipData.subFun = self.onBindGoldSureFun;   -- 确定
    Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
end

function Lua_SecretPanel:onBindGoldSureFun()
    if self.bEnoughBindGold then
        Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 0, 1);
    else
        DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.BIND_GOLD, self.secretVo.oneDrawCost, true, false);
    end
end

function Lua_SecretPanel:onCallBtn2Click(go)
    DataCenter.secretData.drawType = 0;
    self.secretVo = nil;
    local arr = DataCenter.secretUtil.secretInfoArr;
    if arr ~= nil then
        local len = arr:getSize();
        for i = 1, len do
            if arr[i].isGoldDraw == true then
                self.secretVo = arr[i];
                break;
            end
        end
    end

    if self.secretVo == nil then
        return;
    end

    self.bEnoughGoldOne = true;
    local str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.secretVo.oneDrawCost.."[-]";
    if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.secretVo.oneDrawCost then
        self.bEnoughGoldOne = false;
        str = "["..Lua_ColorDefine.RED_STR.."]"..self.secretVo.oneDrawCost.."[-]";
    end

    if DataCenter.neverTip:getNeverValue("Secret_GoldOne") == true then
        if self.bEnoughGoldOne then
            Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 0, 2);
        else
            DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.secretVo.oneDrawCost, true, true);
        end
        return;
    end

    local oneBuyCount = DataCenter.secretUtil.oneBuyCount;

    local tipData = {};
    tipData.des = LanUtil.formateStr(LanUtil.getValue(143445), tostring(self.secretVo.oneDiscount), str, tostring(oneBuyCount), tostring(1));
    tipData.isSecret = true;
    tipData.neverTip = "Secret_GoldOne";
    tipData.owner = self;
    tipData.type = 1;
    tipData.subFun = self.onGoldOneSureFun;   -- 确定
    Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
end

function Lua_SecretPanel:onGoldOneSureFun()
    if self.bEnoughGoldOne then
        Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 0, 2);
    else
        DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.secretVo.oneDrawCost, true, true);
    end
end

function Lua_SecretPanel:onCallBtn3Click(go)
    DataCenter.secretData.drawType = 1;
    self.secretVo = nil;
    local arr = DataCenter.secretUtil.secretInfoArr;
    if arr ~= nil then
        local len = arr:getSize();
        for i = 1, len do
            if arr[i].isGoldDraw == true then
                self.secretVo = arr[i];
                break;
            end
        end
    end

    if self.secretVo == nil then
        return;
    end

    self.bEnoughGoldTen = true;
    local str = "["..Lua_ColorDefine.GREEN_STR.."]"..self.secretVo.tenDrawCost.."[-]";
    if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.secretVo.tenDrawCost then
        self.bEnoughGoldTen = false;
        str = "["..Lua_ColorDefine.RED_STR.."]"..self.secretVo.tenDrawCost.."[-]";
    end

    if DataCenter.neverTip:getNeverValue("Secret_GoldTen") == true then
        if self.bEnoughGoldTen then
            Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 1, 2);
        else
            DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.secretVo.tenDrawCost, true, true);
        end
        return;
    end

    local tenBuyCount = DataCenter.secretUtil.tenBuyCount;

    local tipData = {};
    tipData.des = LanUtil.formateStr(LanUtil.getValue(143445), tostring(self.secretVo.tenDiscount), str, tostring(tenBuyCount), tostring(10));
    tipData.isSecret = true;
    tipData.neverTip = "Secret_GoldTen";
    tipData.owner = self;
    tipData.type = 1;
    tipData.subFun = self.onGoldTenSureFun;   -- 确定
    Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
end

function Lua_SecretPanel:onGoldTenSureFun()
    if self.bEnoughGoldTen then
        Lua_ProxyManager.getProxy("Lua_SecretProxy"):sSecretDraw(self.secretVo.id, 1, 2);
    else
        DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.secretVo.tenDrawCost, true, true);
    end
end




















Lua_SecretRewardItem = class("Lua_SecretRewardItem", Lua_ListCell);
function Lua_SecretRewardItem:ctor(p)
    self:superCall("ctor", p, nil);
end

function Lua_SecretRewardItem:buildShowItem()
    self:superCall("buildShowItem");

    self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(10);
    self.itemImg:setLocation(0, 0, 0);
    self.itemImg:setCanClick(true);

    self.itemName = UICreate.createLabel(self.content, "", 0, -55, 200, 24, 22);
    self.itemName.overflowMethod = UILabel.Overflow.ResizeFreely;
    self.itemName.pivot = UIWidget.Pivot.Center;
    self.itemName:setDepth(3);
end

function Lua_SecretRewardItem:dispose()
    self:superCall("dispose");
end

function Lua_SecretRewardItem:setData(data)
    self.itemImg.data = data;
    self.itemImg:showRoundEff(true);
    self.itemName.text = data.colorName;
end




















Lua_SecretResultItem = class("Lua_SecretResultItem", Lua_DisplayObject);
function Lua_SecretResultItem:ctor(p)
    self:superCall("ctor", p, nil);
end

function Lua_SecretResultItem:buildShowItem()
    self:superCall("buildShowItem");

    self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(10);
    self.itemImg:setLocation(0, 0, 0);
    self.itemImg:setCanClick(true);

    self.itemName = UICreate.createLabel(self.content, "", 0, -55, 200, 24, 22);
    self.itemName.overflowMethod = UILabel.Overflow.ResizeFreely;
    self.itemName.pivot = UIWidget.Pivot.Center;
    self.itemName:setDepth(3);
end

function Lua_SecretResultItem:dispose()
    self:showQualityEff(false);
    self:superCall("dispose");
end

function Lua_SecretResultItem:setData(data)
    self.data = data;
    if data == nil then
        return;
    end

    self:showQualityEff(false);
    self.itemImg.data = data;
    self.itemName.text = data.colorName;
end

function Lua_SecretResultItem:showQualityEff(bShow)
    bShow = bShow == nil and false or bShow;
    if self.data ~= nil and bShow == true then
        local str = "gui_award_light0" .. self.data.color;
        if self.qualityEff == nil then
            self.qualityEff = UICreate.createUIEffect(self.content, "/effects/scsEffects/" .. str, str, 0, 0);
            self.qualityEff:setLoop(true);
            self.qualityEff:setSacle(500, 500, 500);
            self.qualityEff:SetRenderQueue(self.itemImg.item_bg, -1, 2);
        else
            self.qualityEff:setUrl("/effects/scsEffects/" .. str, str);
        end
    else
        if self.qualityEff ~= nil then
            self.qualityEff:dispose();
            self.qualityEff = nil;
        end
    end
end