-- 生肖装备升阶
Lua_ZodiacEquipUpWindow = class("Lua_ZodiacEquipUpWindow", Lua_Window);
function Lua_ZodiacEquipUpWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_ZodiacEquipUpWindow";
	self.skinName = "ZodiacEquipUpWindow_skin";
end

function Lua_ZodiacEquipUpWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(10);
    self.itemImg:setLocation(-200, -220, 0);
    self.itemImg:setCanClick(true);

    self.leftContainer = Lua_DragContainer.new(self.content, 1, Vector4(0, -100, 330, 240));
    self.leftContainer:setLocation(-255, 100, 0);
    self.leftContainer.content.name = "leftContainer";

    self.rightContainer = Lua_DragContainer.new(self.content, 1, Vector4(0, -100, 330, 240));
    self.rightContainer:setLocation(240, 100, 0);
    self.rightContainer.content.name = "rightContainer";

	self.title.text = LanUtil.getValue(143410);
    self.redDot:setEnable(false);
	self.upBtn:addClickFuntion(self, self.onUpBtnClick);

    self:addLuaEvent("ZODIAC_EQUIP_UPGRADE", self, self.updatePanelInfo);
end

function Lua_ZodiacEquipUpWindow:dispose()
	if self.leftContainer ~= nil then
        self.leftContainer:removeAllChildren();
		self.leftContainer:dispose();
		self.leftContainer = nil;
	end

	if self.rightContainer ~= nil then
        self.rightContainer:removeAllChildren();
		self.rightContainer:dispose();
		self.rightContainer = nil;
	end

	self:superCall("dispose");
end

function Lua_ZodiacEquipUpWindow:showWin(param)
    self:superCall("showWin", param);
    
    if type(param) == "table" then
        Lua_ProxyManager.getProxy("Lua_ZodiacProxy"):sUpgradeEquip(self.showData.zodiacIndex, self.showData.itemPart, 0);
    end
end

function Lua_ZodiacEquipUpWindow:updatePanelInfo()
    self:updateLeftInfo();
    self:updateRightInfo();
end

function Lua_ZodiacEquipUpWindow:updateLeftInfo()
    local itemVo = DataCenter.zodiacData.beforeVo;
    if itemVo == nil then
        return;
    end

    itemVo.intensifyLevel = self.showData.intensifyLevel;
    if self.leftItem == nil then
        self.leftItem = Lua_ToolImage.new(self.leftObj);
        self.leftItem:setDepth(10);
        self.leftItem:setLocation(-110, 120, 0);
        self.leftItem:setCanClick(true);
        self.leftItem.content.name = "leftItem";
    end
    self.leftItem.data = itemVo;
    self.leftName.text = itemVo.colorName;
    self.leftPower.text = LanUtil.formateStr(LanUtil.getValue(143424), tostring(itemVo.zongheForce));

    -- 基础属性
    if self.leftBaseProp == nil then
        self.leftBaseProp = Lua_ZodiacEquipUpAttrItem.new(self.leftContainer.content, 1);
        self.leftBaseProp:setData(itemVo);
        self.leftContainer:addSubContainer(self.leftBaseProp, false);
    else
        self.leftBaseProp:setData(itemVo);
    end

    -- 极品属性
    if (itemVo.equipment ~= nil and itemVo.equipment.attr ~= nil and #itemVo.equipment.attr > 0) or itemVo.legend ~= nil then
        if self.leftGoodProp == nil then
            self.leftGoodProp = Lua_ZodiacEquipUpAttrItem.new(self.leftContainer.content, 2);
            self.leftGoodProp:setData(itemVo);
            self.leftContainer:addSubContainer(self.leftGoodProp, false);
        else
            self.leftGoodProp:setData(itemVo);
        end
    end
    self.leftContainer:updateChildPos();

    local upVo = DataCenter.zodiacUtil:getUpgradeVoById(itemVo.id);
    local costVo = upVo.costVo;
    local bagData = DataCenter.packData:getBagType(Lua_PackData.ZODIAC_PACK);
    self.haveNum = bagData:getItemNum(costVo.id);
    self.needNum = costVo.count;
    if self.haveNum >= self.needNum then
        self.redDot:setEnable(true);
    else
        self.redDot:setEnable(false);
    end
    self.itemImg.data = costVo;
    self.itemImg:showNumLimit(self.haveNum, self.needNum, 2);
end

function Lua_ZodiacEquipUpWindow:updateRightInfo()
    local itemVo = DataCenter.zodiacData.afterVo;
    if itemVo == nil then
        return;
    end

    itemVo.intensifyLevel = self.showData.intensifyLevel;
    if self.rightItem == nil then
        self.rightItem = Lua_ToolImage.new(self.rightObj);
        self.rightItem:setDepth(10);
        self.rightItem:setLocation(-110, 120, 0);
        self.rightItem:setCanClick(true);
        self.rightItem.content.name = "rightItem";
    end
    self.rightItem.data = itemVo;
    self.rightName.text = itemVo.colorName;
    self.rightPower.text = LanUtil.formateStr(LanUtil.getValue(143424), tostring(itemVo.zongheForce));

    -- 基础属性
    if self.rightBaseProp == nil then
        self.rightBaseProp = Lua_ZodiacEquipUpAttrItem.new(self.rightContainer.content, 1);
        self.rightBaseProp:setData(itemVo);
        self.rightContainer:addSubContainer(self.rightBaseProp, false);
    else
        self.rightBaseProp:setData(itemVo);
    end

    -- 极品属性
    if (itemVo.equipment ~= nil and itemVo.equipment.attr ~= nil and #itemVo.equipment.attr > 0) or itemVo.legend ~= nil then
        if self.rightGoodProp == nil then
            self.rightGoodProp = Lua_ZodiacEquipUpAttrItem.new(self.rightContainer.content, 2);
            self.rightGoodProp:setData(itemVo);
            self.rightContainer:addSubContainer(self.rightGoodProp, false);
        else
            self.rightGoodProp:setData(itemVo);
        end
    end
    self.rightContainer:updateChildPos();
end

function Lua_ZodiacEquipUpWindow:onUpBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
        OperateAlert.show(LanUtil.getValue(121419));
        return;
    end
    self.clickTime = getTime();
    
    if self.haveNum < self.needNum then
        OperateAlert.show(LanUtil.getValue(143468));
        return;
    end

    Lua_ProxyManager.getProxy("Lua_ZodiacProxy"):sUpgradeEquip(self.showData.zodiacIndex, self.showData.itemPart, 1);

    -- 策划需求：进阶成功关闭进阶界面
    OperateAlert.show(LanUtil.getValue(143470));
    self:hide();
end




















Lua_ZodiacEquipUpAttrItem = class("Lua_ZodiacEquipUpAttrItem", Lua_DragContainerItem);
function Lua_ZodiacEquipUpAttrItem:ctor(p, t)
    self.t = t; -- 1基础属性 2极品属性
    self:superCall("ctor", p, "ZodiacEquipUpAttrItem_skin");
end

function Lua_ZodiacEquipUpAttrItem:setData(val)
    if self.t == 1 then
        self.desLabel.text = LanUtil.getValue(143464);
        self.propTxt.text = val.equipAttrsStr;
    elseif self.t == 2 then
        local str = "";
        if val.equipment ~= nil and val.equipment.attr ~= nil and #val.equipment.attr > 0 then
            self.desLabel.text = LanUtil.getValue(110852);
            for i = 1,#val.equipment.attr do
                local v = val.equipment.attr[i];
                str = str..Lua_PackUtil.genAttName(v);
                if i ~= #val.equipment.attr then
                    str = str.."\n";
                end
            end
        else
            self.desLabel.text = LanUtil.getValue(110853);
            str = val.legend;
        end
        self.propTxt.text = str;
    end
end

function Lua_ZodiacEquipUpAttrItem:getHeight()
    return self.propTxt.height + 50;
end