checkRequire("Lua_ZodiacEquipHoleItem");
checkRequire("Lua_ZodiacSkillItem");
Lua_ZodiacPanel = class("Lua_ZodiacPanel", Lua_DisplayObject);
function Lua_ZodiacPanel:ctor(p)	
	self:superCall("ctor", p, "ZodiacPanel_skin");
end

function Lua_ZodiacPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.holeArr = Array();
	local holePos = {{-275, 167}, {-37, 170}, {-275, -105}, {-37, -105}};
	for i,v in ipairs(holePos) do
		local holeItem = Lua_ZodiacEquipHoleItem.new(self.content);
		holeItem:setLocation(v[1], v[2], 0);
		self.holeArr:add(holeItem);
	end

	self.skillItem = Lua_ZodiacSkillItem.new(self.content);
	self.skillItem:setLocation(320, -120, 0);

	self.headImg = UICreate.createImage(self.content, "", -156, 25, 0, 0);
	self.headImg:setDepth(10);

	self.btnList = Lua_DragCustomBtnList.new(self.content, 1, Vector4(0, -266, 188, 540));
	self.btnList:setLocation(-529, 270, 0);
	self.btnList:setMainBtnCell(Lua_ZodiacBtnMainCell, 170, 70, 0, 0);
	self.btnList:setSubBtnCell(Lua_ZodiacBtnSubCell, 164, 70, 0, 0);
	-- self.btnList.clickDrawBack = true;
	self.btnList:setDepth(5);

	self.propList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 340, 200));
    self.propList:setLocation(320, 80, 0);
    self.propList:setListCell(Lua_ZodiacPropItem, 37, 90, 1);

    self.costItem.clickScale = false;
	self.costItem:addClickFuntion(self, self.onCostItemClick);
	self.btnPower:addClickFuntion(self, self.onPowerBtnClick);
	self.helpBtn:addClickFuntion(self, self.onHelpBtnClick);

	self.addRedDot:setEnable(false);
	self.addBtn:addClickFuntion(self, self.onAddBtnClick);

	self.packRedDot:setEnable(false);
	self.packBtn:addClickFuntion(self, self.onPackBtnClick);

	self.intensifyRedDot:setEnable(false);
	self.intensifyBtn:addClickFuntion(self, self.onIntensifyBtnClick);

	self.resolveRedDot:setEnable(false);
	self.resolveBtn:addClickFuntion(self, self.onResolveBtnClick);

	Lua_ProxyManager.getProxy("Lua_ZodiacProxy"):sZodiacInfo();
	self:addLuaEvent("UPDATE_ALL_ZODIAC", self, self.updatePanelInfo);
	self:updatePanelInfo();
end

function Lua_ZodiacPanel:dispose()
	if self.btnList == nil then
		self.btnList:dispose();
		self.btnList = nil;
	end

	if self.propList ~= nil then
		self.propList:dispose();
		self.propList = nil;
	end

	for i = 1, self.holeArr:getSize() do
		self.holeArr[i]:dispose();
	end
	self.holeArr:clear();

	DataCenter.zodiacData.selectMainIndex = 1;
	DataCenter.zodiacData.selectZodiacId = 1;

	self:superCall("dispose");
end

function Lua_ZodiacPanel:updatePanelInfo()
	local selectMainIndex = DataCenter.zodiacData.selectMainIndex;
	local selectSubIndex = DataCenter.zodiacData.selectSubIndex;

	self.btnList:setData(DataCenter.zodiacUtil.zodiacArr, self, self.onBtnClick);
	self.btnList:setMainSlected(selectMainIndex, selectSubIndex);

	local intensifyCostCount = DataCenter.zodiacData.intensifyCostCount;
	self.costCount.text = tostring(intensifyCostCount);

	self.addRedDot:setEnable(DataCenter.redDotData:getRedDotStateByEventId(22075));
	self.resolveRedDot:setEnable(DataCenter.redDotData:getRedDotStateByEventId(22072));
end

function Lua_ZodiacPanel:onBtnClick(data)
	self.data = data;

	DataCenter.zodiacData.selectMainIndex = data.mainType;
	DataCenter.zodiacData.selectZodiacId = data.id;

	local dic = data.holeVoDic;
	for k,v in pairs(dic) do
		if v.holePart ~= nil then
			self.holeArr[v.holePart]:setData(v);
		end
	end

	self.propList:setLuaArrayData(data.attrsArr, false);
	self.skillItem:setData(data.skillInfo);
	self.tipsLabel.text = data.skillActivateTips;
	self.headImg:setUrl(data.headStr);
	self.useSkill.text = LanUtil.formateStr(LanUtil.getValue(143404), tostring(DataCenter.zodiacData.skillCount), tostring(DataCenter.zodiacData.skillTotal));

	if data.isHaveEquipWear or data.isHaveGoodOrderEquip then
		self.packRedDot:setEnable(true);
	else
		self.packRedDot:setEnable(false);
	end
	if data.isEquipCanIntensify or data.isEquipCanUpgrade then
		self.intensifyRedDot:setEnable(true);
	else
		self.intensifyRedDot:setEnable(false);
	end
end

function Lua_ZodiacPanel:onCostItemClick(go)
	Lua_PackUtil.showItemInfo(DataCenter.zodiacUtil.intensifyCostVo);
end

function Lua_ZodiacPanel:onPowerBtnClick(go)
	Lua_WindowUtil.openWin("Lua_ZodiacPowerWindow", WinParam.ACTION_OPEN);
end

function Lua_ZodiacPanel:onHelpBtnClick(go)
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_OPEN, LanUtil.getValue(143407));
end

function Lua_ZodiacPanel:onAddBtnClick(go)
	Lua_WindowUtil.openWin("Lua_ZodiacSkillExtendWindow", WinParam.ACTION_OPEN);
end

function Lua_ZodiacPanel:onPackBtnClick(go)
	Lua_WindowUtil.openWin("Lua_ZodiacPackWindow", WinParam.ACTION_OPEN);
end

function Lua_ZodiacPanel:onIntensifyBtnClick(go)
	Lua_WindowUtil.openWin("Lua_ZodiacIntensifyWindow", WinParam.ACTION_OPEN);
end

function Lua_ZodiacPanel:onResolveBtnClick(go)
	Lua_WindowUtil.openWin("Lua_ZodiacResolveWindow", WinParam.ACTION_OPEN);
end




















Lua_ZodiacBtnMainCell = class("Lua_ZodiacBtnMainCell", Lua_DragCustomBtnListCell);
function Lua_ZodiacBtnMainCell:ctor(p, btnType, cellWidth, cellHeight, offsetX, offsetY, skin)
    self:superCall("ctor", p, btnType, cellWidth, cellHeight, offsetX, offsetY, "ZodiacBtnMain_skin");
end

function Lua_ZodiacBtnMainCell:buildShowItem()
    self:superCall("buildShowItem");
    self.redDot:setEnable(false);
end

function Lua_ZodiacBtnMainCell:dispose()
    self:superCall("dispose");
end

function Lua_ZodiacBtnMainCell:updateData()
	local bShow = false
    local arr = self._data.sub;
    local len = arr:getSize();
    if arr ~= nil and len > 0 then
    	for i = 1, len do
    		local vo = arr[i];
    		if vo ~= nil and (vo.isSkillCanUse or vo.isHaveEquipWear or vo.isHaveGoodOrderEquip or vo.isEquipCanIntensify or vo.isEquipCanUpgrade) then
    			bShow = true;
    			break;
    		end
    	end
    end
    self.redDot:setEnable(bShow);
end

function Lua_ZodiacBtnMainCell:setSelected(val)
	self:superCall("setSelected", val);
    if val == true then
    	self.btnBg:setAltas("iconantlas1", "tab4_souchong_select");
    	self.btnLabel.text = "[883A0B]" .. self._data.name .. "[-]";
    else
    	self.btnBg:setAltas("iconantlas1", "tab4_souchong_normal");
    	self.btnLabel.text = "[192E41]" .. self._data.name .. "[-]";
    end
end










Lua_ZodiacBtnSubCell = class("Lua_ZodiacBtnSubCell", Lua_DragCustomBtnListCell);
function Lua_ZodiacBtnSubCell:ctor(p, btnType, cellWidth, cellHeight, offsetX, offsetY, skin)
    self:superCall("ctor", p, btnType, cellWidth, cellHeight, offsetX, offsetY, "ZodiacBtnSub_skin");
end

function Lua_ZodiacBtnSubCell:buildShowItem()
    self:superCall("buildShowItem");
    self.tabObj:SetActive(false);
    self.redDot:setEnable(false);
end

function Lua_ZodiacBtnSubCell:dispose()
    self:superCall("dispose");
end

function Lua_ZodiacBtnSubCell:updateData()
	self.fraction.text = LanUtil.formateStr(LanUtil.getValue(143424), tostring(self._data.totalForce));
	if self._data.skillState == 2 then -- 已使用
		self.tabObj:SetActive(true);
	else
		self.tabObj:SetActive(false);
	end
	if self._data.isSkillCanUse or self._data.isHaveEquipWear or self._data.isHaveGoodOrderEquip or self._data.isEquipCanIntensify or self._data.isEquipCanUpgrade then
		self.redDot:setEnable(true);
	else
		self.redDot:setEnable(false);
	end
end

function Lua_ZodiacBtnSubCell:setSelected(val)
	self:superCall("setSelected", val);
    if val == true then
    	self.btnBg:setAltas("zodiac", "subBtn_yes");
    	self.name.text = "[883A0B]" .. self._data.name .. "[-]";
    else
    	self.btnBg:setAltas("zodiac", "subBtn_no");
    	self.name.text = "[192E41]" .. self._data.name .. "[-]";
    end
end










Lua_ZodiacPropItem = class("Lua_ZodiacPropItem", Lua_ListCell);
function Lua_ZodiacPropItem:ctor(p)
    self:superCall("ctor", p, nil);
end

function Lua_ZodiacPropItem:buildShowItem()
	self:superCall("buildShowItem");

	self.propTxt = UICreate.createLabel(self.content, "", 0, 0, 200, 24, 24);
    self.propTxt.pivot = UIWidget.Pivot.Left;
    self.propTxt.overflowMethod = UILabel.Overflow.ResizeFreely;
    self.propTxt:setDepth(10);
    self.propTxt:setLocation(0, 0, 0);
end

function Lua_ZodiacPropItem:dispose()
	self:superCall("dispose");
end

function Lua_ZodiacPropItem:setData(data)
	local str = "[3F6182]"..data.name.."[-]"; -- 极品属性

	if data.baseValue ~= nil then
		str = "[3F6182]"..data.name.."：[-]".."[192E41]"..data.baseValue.."[-]";
	end

	if data.intensifyValue ~= nil and data.intensifyValue ~= 0 then -- 强化值
		str = str .. "      [13A100]+"..data.intensifyValue.."[-]";
	end
	self.propTxt.text = str;
end